pub struct GoogleCloudDialogflowV2beta1AgentAssistantRecord {
pub article_suggestion_answer: Option<GoogleCloudDialogflowV2beta1ArticleAnswer>,
pub dialogflow_assist_answer: Option<GoogleCloudDialogflowV2beta1DialogflowAssistAnswer>,
pub faq_answer: Option<GoogleCloudDialogflowV2beta1FaqAnswer>,
}Expand description
Represents a record of a human agent assistant answer.
This type is not used in any activity, and only used as part of another schema.
Fields
article_suggestion_answer: Option<GoogleCloudDialogflowV2beta1ArticleAnswer>Output only. The article suggestion answer.
dialogflow_assist_answer: Option<GoogleCloudDialogflowV2beta1DialogflowAssistAnswer>Output only. The Dialogflow assist answer.
faq_answer: Option<GoogleCloudDialogflowV2beta1FaqAnswer>Output only. The FAQ answer.