pub struct GoogleCloudDialogflowV2beta1AnnotatedMessagePart {
pub entity_type: Option<String>,
pub formatted_value: Option<Value>,
pub text: Option<String>,
}Expand description
Represents a part of a message possibly annotated with an entity. The part can be an entity or purely a part of the message between two entities or message start/end.
This type is not used in any activity, and only used as part of another schema.
Fields
entity_type: Option<String>Optional. The Dialogflow system entity type of this message part. If this is empty, Dialogflow could not annotate the phrase part with a system entity.
formatted_value: Option<Value>Optional. The Dialogflow system entity formatted value of this message part. For example for a system entity of type @sys.unit-currency, this may contain: { “amount”: 5, “currency”: “USD” }
text: Option<String>Required. A part of a message possibly annotated with an entity.