pub struct GoogleCloudDialogflowV2beta1AnswerFeedback {
pub agent_assistant_detail_feedback: Option<GoogleCloudDialogflowV2beta1AgentAssistantFeedback>,
pub click_time: Option<DateTime<Utc>>,
pub clicked: Option<bool>,
pub correctness_level: Option<String>,
pub display_time: Option<DateTime<Utc>>,
pub displayed: Option<bool>,
}Expand description
Represents feedback the customer has about the quality & correctness of a certain answer in a conversation.
This type is not used in any activity, and only used as part of another schema.
Fields
agent_assistant_detail_feedback: Option<GoogleCloudDialogflowV2beta1AgentAssistantFeedback>Optional. Detail feedback of agent assistant suggestions.
click_time: Option<DateTime<Utc>>Time when the answer/item was clicked.
clicked: Option<bool>Indicates whether the answer/item was clicked by the human agent or not. Default to false. For knowledge search, the answer record is considered to be clicked if the answer was copied or any URI was clicked.
correctness_level: Option<String>The correctness level of the specific answer.
display_time: Option<DateTime<Utc>>Time when the answer/item was displayed.
displayed: Option<bool>Indicates whether the answer/item was displayed to the human agent in the agent desktop UI. Default to false.