pub struct GoogleCloudDialogflowV2beta1ArticleAnswer {
pub answer_record: Option<String>,
pub metadata: Option<HashMap<String, String>>,
pub snippets: Option<Vec<String>>,
pub title: Option<String>,
pub uri: Option<String>,
}Expand description
Represents article answer.
This type is not used in any activity, and only used as part of another schema.
Fields
answer_record: Option<String>The name of answer record, in the format of “projects//locations//answerRecords/”
metadata: Option<HashMap<String, String>>A map that contains metadata about the answer and the document from which it originates.
snippets: Option<Vec<String>>Output only. Article snippets.
title: Option<String>The article title.
uri: Option<String>The article URI.