pub struct GoogleCloudDialogflowV2beta1AssistQueryParameters {
pub documents_metadata_filters: Option<HashMap<String, String>>,
}Expand description
Represents the parameters of human assist query.
This type is not used in any activity, and only used as part of another schema.
Fields
documents_metadata_filters: Option<HashMap<String, String>>Key-value filters on the metadata of documents returned by article suggestion. If specified, article suggestion only returns suggested documents that match all filters in their Document.metadata. Multiple values for a metadata key should be concatenated by comma. For example, filters to match all documents that have ‘US’ or ‘CA’ in their market metadata values and ‘agent’ in their user metadata values will be documents_metadata_filters { key: "market" value: "US,CA" } documents_metadata_filters { key: "user" value: "agent" }