GoogleCloudDialogflowV2beta1AutomatedAgentReply

Struct GoogleCloudDialogflowV2beta1AutomatedAgentReply 

pub struct GoogleCloudDialogflowV2beta1AutomatedAgentReply {
    pub allow_cancellation: Option<bool>,
    pub automated_agent_reply_type: Option<String>,
    pub call_companion_auth_code: Option<Vec<u8>>,
    pub cx_current_page: Option<String>,
    pub cx_session_parameters: Option<HashMap<String, Value>>,
    pub detect_intent_response: Option<GoogleCloudDialogflowV2beta1DetectIntentResponse>,
    pub event: Option<String>,
    pub intent: Option<String>,
    pub match_confidence: Option<f32>,
    pub parameters: Option<HashMap<String, Value>>,
    pub response_messages: Option<Vec<GoogleCloudDialogflowV2beta1ResponseMessage>>,
}
Represents a response from an automated agent.

This type is not used in any activity, and only used as part of another schema.

Fields

allow_cancellation: Option<bool>

Indicates whether the partial automated agent reply is interruptible when a later reply message arrives. e.g. if the agent specified some music as partial response, it can be cancelled.

automated_agent_reply_type: Option<String>

AutomatedAgentReply type.

call_companion_auth_code: Option<Vec<u8>>

The auth code for accessing Call Companion UI.

cx_current_page: Option<String>

The unique identifier of the current Dialogflow CX conversation page. Format: projects//locations//agents//flows//pages/.

cx_session_parameters: Option<HashMap<String, Value>>

The collection of current Dialogflow CX agent session parameters at the time of this response. Deprecated: Use parameters instead.

detect_intent_response: Option<GoogleCloudDialogflowV2beta1DetectIntentResponse>

Response of the Dialogflow Sessions.DetectIntent call.

event: Option<String>

Event name if an event is triggered for the query.

intent: Option<String>

Name of the intent if an intent is matched for the query. For a V2 query, the value format is projects//locations/ /agent/intents/. For a V3 query, the value format is projects//locations/ /agents//intents/.

match_confidence: Option<f32>

The confidence of the match. Values range from 0.0 (completely uncertain) to 1.0 (completely certain). This value is for informational purpose only and is only used to help match the best intent within the classification threshold. This value may change for the same end-user expression at any time due to a model retraining or change in implementation.

parameters: Option<HashMap<String, Value>>

The collection of current parameters at the time of this response.

response_messages: Option<Vec<GoogleCloudDialogflowV2beta1ResponseMessage>>

Response messages from the automated agent.