pub struct GoogleCloudDialogflowV2beta1DialogflowAssistAnswer {
pub answer_record: Option<String>,
pub intent_suggestion: Option<GoogleCloudDialogflowV2beta1IntentSuggestion>,
pub query_result: Option<GoogleCloudDialogflowV2beta1QueryResult>,
}Expand description
Represents a Dialogflow assist answer.
This type is not used in any activity, and only used as part of another schema.
Fields
answer_record: Option<String>The name of answer record, in the format of “projects//locations//answerRecords/”
intent_suggestion: Option<GoogleCloudDialogflowV2beta1IntentSuggestion>An intent suggestion generated from conversation.
query_result: Option<GoogleCloudDialogflowV2beta1QueryResult>Result from v2 agent.