pub struct GoogleCloudDialogflowV2beta1EntityTypeBatch {
pub entity_types: Option<Vec<GoogleCloudDialogflowV2beta1EntityType>>,
}Expand description
This message is a wrapper around a collection of entity types.
This type is not used in any activity, and only used as part of another schema.
Fields
entity_types: Option<Vec<GoogleCloudDialogflowV2beta1EntityType>>A collection of entity types.