pub struct GoogleCloudDialogflowV2beta1HumanAgentAssistantConfigSuggestionConfig {
pub disable_high_latency_features_sync_delivery: Option<bool>,
pub feature_configs: Option<Vec<GoogleCloudDialogflowV2beta1HumanAgentAssistantConfigSuggestionFeatureConfig>>,
pub generators: Option<Vec<String>>,
pub group_suggestion_responses: Option<bool>,
}Expand description
Detail human agent assistant config.
This type is not used in any activity, and only used as part of another schema.
Fields
disable_high_latency_features_sync_delivery: Option<bool>Optional. When disable_high_latency_features_sync_delivery is true and using the AnalyzeContent API, we will not deliver the responses from high latency features in the API response. The human_agent_assistant_config.notification_config must be configured and enable_event_based_suggestion must be set to true to receive the responses from high latency features in Pub/Sub. High latency feature(s): KNOWLEDGE_ASSIST
feature_configs: Option<Vec<GoogleCloudDialogflowV2beta1HumanAgentAssistantConfigSuggestionFeatureConfig>>Configuration of different suggestion features. One feature can have only one config.
generators: Option<Vec<String>>Optional. List of various generator resource names used in the conversation profile.
group_suggestion_responses: Option<bool>If group_suggestion_responses is false, and there are multiple feature_configs in event based suggestion or StreamingAnalyzeContent, we will try to deliver suggestions to customers as soon as we get new suggestion. Different type of suggestions based on the same context will be in separate Pub/Sub event or StreamingAnalyzeContentResponse. If group_suggestion_responses set to true. All the suggestions to the same participant based on the same context will be grouped into a single Pub/Sub event or StreamingAnalyzeContentResponse.