pub struct GoogleCloudDialogflowV2beta1InputAudioConfig {Show 14 fields
pub audio_encoding: Option<String>,
pub barge_in_config: Option<GoogleCloudDialogflowV2beta1BargeInConfig>,
pub default_no_speech_timeout: Option<Duration>,
pub disable_no_speech_recognized_event: Option<bool>,
pub enable_automatic_punctuation: Option<bool>,
pub enable_word_info: Option<bool>,
pub language_code: Option<String>,
pub model: Option<String>,
pub model_variant: Option<String>,
pub opt_out_conformer_model_migration: Option<bool>,
pub phrase_hints: Option<Vec<String>>,
pub sample_rate_hertz: Option<i32>,
pub single_utterance: Option<bool>,
pub speech_contexts: Option<Vec<GoogleCloudDialogflowV2beta1SpeechContext>>,
}Expand description
Instructs the speech recognizer on how to process the audio content.
This type is not used in any activity, and only used as part of another schema.
Fields
audio_encoding: Option<String>Required. Audio encoding of the audio content to process.
barge_in_config: Option<GoogleCloudDialogflowV2beta1BargeInConfig>Configuration of barge-in behavior during the streaming of input audio.
default_no_speech_timeout: Option<Duration>If set, use this no-speech timeout when the agent does not provide a no-speech timeout itself.
disable_no_speech_recognized_event: Option<bool>Only used in Participants.AnalyzeContent and Participants.StreamingAnalyzeContent. If false and recognition doesn’t return any result, trigger NO_SPEECH_RECOGNIZED event to Dialogflow agent.
enable_automatic_punctuation: Option<bool>Enable automatic punctuation option at the speech backend.
enable_word_info: Option<bool>If true, Dialogflow returns SpeechWordInfo in StreamingRecognitionResult with information about the recognized speech words, e.g. start and end time offsets. If false or unspecified, Speech doesn’t return any word-level information.
language_code: Option<String>Required. The language of the supplied audio. Dialogflow does not do translations. See Language Support for a list of the currently supported language codes. Note that queries in the same session do not necessarily need to specify the same language.
model: Option<String>Optional. Which Speech model to select for the given request. For more information, see Speech models.
model_variant: Option<String>Which variant of the Speech model to use.
opt_out_conformer_model_migration: Option<bool>If true, the request will opt out for STT conformer model migration. This field will be deprecated once force migration takes place in June 2024. Please refer to Dialogflow ES Speech model migration.
phrase_hints: Option<Vec<String>>A list of strings containing words and phrases that the speech recognizer should recognize with higher likelihood. See the Cloud Speech documentation for more details. This field is deprecated. Please use speech_contexts instead. If you specify both phrase_hints and speech_contexts, Dialogflow will treat the phrase_hints as a single additional SpeechContext.
sample_rate_hertz: Option<i32>Required. Sample rate (in Hertz) of the audio content sent in the query. Refer to Cloud Speech API documentation for more details.
single_utterance: Option<bool>If false (default), recognition does not cease until the client closes the stream. If true, the recognizer will detect a single spoken utterance in input audio. Recognition ceases when it detects the audio’s voice has stopped or paused. In this case, once a detected intent is received, the client should close the stream and start a new request with a new stream as needed. Note: This setting is relevant only for streaming methods. Note: When specified, InputAudioConfig.single_utterance takes precedence over StreamingDetectIntentRequest.single_utterance.
speech_contexts: Option<Vec<GoogleCloudDialogflowV2beta1SpeechContext>>Context information to assist speech recognition. See the Cloud Speech documentation for more details.