pub struct GoogleCloudDialogflowV2beta1IntentBatch {
pub intents: Option<Vec<GoogleCloudDialogflowV2beta1Intent>>,
}Expand description
This message is a wrapper around a collection of intents.
This type is not used in any activity, and only used as part of another schema.
Fields
intents: Option<Vec<GoogleCloudDialogflowV2beta1Intent>>A collection of intents.