pub struct GoogleCloudDialogflowV2beta1IntentInput {
pub intent: Option<String>,
pub language_code: Option<String>,
}Expand description
Represents the intent to trigger programmatically rather than as a result of natural language processing. The intent input is only used for V3 agent.
This type is not used in any activity, and only used as part of another schema.
Fields
intent: Option<String>Required. The unique identifier of the intent in V3 agent. Format: projects//locations//locations//agents//intents/.
language_code: Option<String>Required. The language of this conversational query. See Language Support for a list of the currently supported language codes.