GoogleCloudDialogflowV2beta1IntentMessageLinkOutSuggestion

Struct GoogleCloudDialogflowV2beta1IntentMessageLinkOutSuggestion 

pub struct GoogleCloudDialogflowV2beta1IntentMessageLinkOutSuggestion {
    pub destination_name: Option<String>,
    pub uri: Option<String>,
}
The suggestion chip message that allows the user to jump out to the app or website associated with this agent.

This type is not used in any activity, and only used as part of another schema.

Fields

destination_name: Option<String>

Required. The name of the app or site this chip is linking to.

uri: Option<String>

Required. The URI of the app or site to open when the user taps the suggestion chip.