GoogleCloudDialogflowV2beta1IntentMessageRbmCarouselCard

Struct GoogleCloudDialogflowV2beta1IntentMessageRbmCarouselCard 

pub struct GoogleCloudDialogflowV2beta1IntentMessageRbmCarouselCard {
    pub card_contents: Option<Vec<GoogleCloudDialogflowV2beta1IntentMessageRbmCardContent>>,
    pub card_width: Option<String>,
}
Carousel Rich Business Messaging (RBM) rich card. Rich cards allow you to respond to users with more vivid content, e.g. with media and suggestions. If you want to show a single card with more control over the layout, please use RbmStandaloneCard instead.

This type is not used in any activity, and only used as part of another schema.

Fields

card_contents: Option<Vec<GoogleCloudDialogflowV2beta1IntentMessageRbmCardContent>>

Required. The cards in the carousel. A carousel must have at least 2 cards and at most 10.

card_width: Option<String>

Required. The width of the cards in the carousel.