pub struct GoogleCloudDialogflowV2beta1IntentParameter {
pub default_value: Option<String>,
pub display_name: Option<String>,
pub entity_type_display_name: Option<String>,
pub is_list: Option<bool>,
pub mandatory: Option<bool>,
pub name: Option<String>,
pub prompts: Option<Vec<String>>,
pub value: Option<String>,
}Expand description
Represents intent parameters.
This type is not used in any activity, and only used as part of another schema.
Fields
default_value: Option<String>Optional. The default value to use when the value yields an empty result. Default values can be extracted from contexts by using the following syntax: #context_name.parameter_name.
display_name: Option<String>Required. The name of the parameter.
entity_type_display_name: Option<String>Optional. The name of the entity type, prefixed with @, that describes values of the parameter. If the parameter is required, this must be provided.
is_list: Option<bool>Optional. Indicates whether the parameter represents a list of values.
mandatory: Option<bool>Optional. Indicates whether the parameter is required. That is, whether the intent cannot be completed without collecting the parameter value.
name: Option<String>The unique identifier of this parameter.
prompts: Option<Vec<String>>Optional. The collection of prompts that the agent can present to the user in order to collect a value for the parameter.
value: Option<String>Optional. The definition of the parameter value. It can be: - a constant string, - a parameter value defined as $parameter_name, - an original parameter value defined as $parameter_name.original, - a parameter value from some context defined as #context_name.parameter_name.