pub struct GoogleCloudDialogflowV2beta1IntentTrainingPhrasePart {
pub alias: Option<String>,
pub entity_type: Option<String>,
pub text: Option<String>,
pub user_defined: Option<bool>,
}Expand description
Represents a part of a training phrase.
This type is not used in any activity, and only used as part of another schema.
Fields
alias: Option<String>Optional. The parameter name for the value extracted from the annotated part of the example. This field is required for annotated parts of the training phrase.
entity_type: Option<String>Optional. The entity type name prefixed with @. This field is required for annotated parts of the training phrase.
text: Option<String>Required. The text for this part.
user_defined: Option<bool>Optional. Indicates whether the text was manually annotated. This field is set to true when the Dialogflow Console is used to manually annotate the part. When creating an annotated part with the API, you must set this to true.