pub struct GoogleCloudDialogflowV2beta1KnowledgeAssistAnswer {
pub answer_record: Option<String>,
pub suggested_query: Option<GoogleCloudDialogflowV2beta1KnowledgeAssistAnswerSuggestedQuery>,
pub suggested_query_answer: Option<GoogleCloudDialogflowV2beta1KnowledgeAssistAnswerKnowledgeAnswer>,
}Expand description
Represents a Knowledge Assist answer.
This type is not used in any activity, and only used as part of another schema.
Fields
answer_record: Option<String>The name of the answer record. Format: projects//locations//answer Records/.
suggested_query: Option<GoogleCloudDialogflowV2beta1KnowledgeAssistAnswerSuggestedQuery>The query suggested based on the context. Suggestion is made only if it is different from the previous suggestion.
suggested_query_answer: Option<GoogleCloudDialogflowV2beta1KnowledgeAssistAnswerKnowledgeAnswer>The answer generated for the suggested query. Whether or not an answer is generated depends on how confident we are about the generated query.