pub struct GoogleCloudDialogflowV2beta1KnowledgeAssistAnswerKnowledgeAnswer {
pub answer_text: Option<String>,
pub faq_source: Option<GoogleCloudDialogflowV2beta1KnowledgeAssistAnswerKnowledgeAnswerFaqSource>,
pub generative_source: Option<GoogleCloudDialogflowV2beta1KnowledgeAssistAnswerKnowledgeAnswerGenerativeSource>,
}Expand description
Represents an answer from Knowledge. Currently supports FAQ and Generative answers.
This type is not used in any activity, and only used as part of another schema.
Fields
answer_text: Option<String>The piece of text from the source that answers this suggested query.
faq_source: Option<GoogleCloudDialogflowV2beta1KnowledgeAssistAnswerKnowledgeAnswerFaqSource>Populated if the prediction came from FAQ.
generative_source: Option<GoogleCloudDialogflowV2beta1KnowledgeAssistAnswerKnowledgeAnswerGenerativeSource>Populated if the prediction was Generative.