pub struct GoogleCloudDialogflowV2beta1ListConversationProfilesResponse {
pub conversation_profiles: Option<Vec<GoogleCloudDialogflowV2beta1ConversationProfile>>,
pub next_page_token: Option<String>,
}Expand description
The response message for ConversationProfiles.ListConversationProfiles.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- conversation profiles list projects (response)
- locations conversation profiles list projects (response)
Fields
conversation_profiles: Option<Vec<GoogleCloudDialogflowV2beta1ConversationProfile>>The list of project conversation profiles. There is a maximum number of items returned based on the page_size field in the request.
next_page_token: Option<String>Token to retrieve the next page of results, or empty if there are no more results in the list.