pub struct GoogleCloudDialogflowV2beta1ListConversationsResponse {
pub conversations: Option<Vec<GoogleCloudDialogflowV2beta1Conversation>>,
pub next_page_token: Option<String>,
}Expand description
The response message for Conversations.ListConversations.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- conversations list projects (response)
- locations conversations list projects (response)
Fields
conversations: Option<Vec<GoogleCloudDialogflowV2beta1Conversation>>The list of conversations. There will be a maximum number of items returned based on the page_size field in the request.
next_page_token: Option<String>Token to retrieve the next page of results, or empty if there are no more results in the list.