pub struct GoogleCloudDialogflowV2beta1ListGeneratorsResponse {
pub generators: Option<Vec<GoogleCloudDialogflowV2beta1Generator>>,
pub next_page_token: Option<String>,
}Expand description
Response of ListGenerators.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- generators list projects (response)
- locations generators list projects (response)
Fields
generators: Option<Vec<GoogleCloudDialogflowV2beta1Generator>>List of generators retrieved.
next_page_token: Option<String>Token to retrieve the next page of results, or empty if there are no more results in the list.