pub struct GoogleCloudDialogflowV2beta1ListKnowledgeBasesResponse {
pub knowledge_bases: Option<Vec<GoogleCloudDialogflowV2beta1KnowledgeBase>>,
pub next_page_token: Option<String>,
}Expand description
Response message for KnowledgeBases.ListKnowledgeBases.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- agent knowledge bases list projects (response)
- knowledge bases list projects (response)
- locations knowledge bases list projects (response)
Fields
knowledge_bases: Option<Vec<GoogleCloudDialogflowV2beta1KnowledgeBase>>The list of knowledge bases.
next_page_token: Option<String>Token to retrieve the next page of results, or empty if there are no more results in the list.