pub struct GoogleCloudDialogflowV2beta1ListVersionsResponse {
pub next_page_token: Option<String>,
pub versions: Option<Vec<GoogleCloudDialogflowV2beta1Version>>,
}Expand description
The response message for Versions.ListVersions.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- agent versions list projects (response)
- locations agent versions list projects (response)
Fields
next_page_token: Option<String>Token to retrieve the next page of results, or empty if there are no more results in the list.
versions: Option<Vec<GoogleCloudDialogflowV2beta1Version>>The list of agent versions. There will be a maximum number of items returned based on the page_size field in the request.