pub struct GoogleCloudDialogflowV2beta1LoggingConfig {
pub enable_stackdriver_logging: Option<bool>,
}Expand description
Defines logging behavior for conversation lifecycle events.
This type is not used in any activity, and only used as part of another schema.
Fields
enable_stackdriver_logging: Option<bool>Whether to log conversation events like CONVERSATION_STARTED to Stackdriver in the conversation project as JSON format ConversationEvent protos.