pub struct GoogleCloudDialogflowV2beta1Message {
pub content: Option<String>,
pub create_time: Option<DateTime<Utc>>,
pub language_code: Option<String>,
pub message_annotation: Option<GoogleCloudDialogflowV2beta1MessageAnnotation>,
pub name: Option<String>,
pub participant: Option<String>,
pub participant_role: Option<String>,
pub send_time: Option<DateTime<Utc>>,
pub sentiment_analysis: Option<GoogleCloudDialogflowV2beta1SentimentAnalysisResult>,
}Expand description
Represents a message posted into a conversation.
This type is not used in any activity, and only used as part of another schema.
Fields
content: Option<String>Required. The message content.
create_time: Option<DateTime<Utc>>Output only. The time when the message was created in Contact Center AI.
language_code: Option<String>Optional. The message language. This should be a BCP-47 language tag. Example: “en-US”.
message_annotation: Option<GoogleCloudDialogflowV2beta1MessageAnnotation>Output only. The annotation for the message.
name: Option<String>Optional. The unique identifier of the message. Format: projects//locations//conversations//messages/.
participant: Option<String>Output only. The participant that sends this message.
participant_role: Option<String>Output only. The role of the participant.
send_time: Option<DateTime<Utc>>Optional. The time when the message was sent.
sentiment_analysis: Option<GoogleCloudDialogflowV2beta1SentimentAnalysisResult>Output only. The sentiment analysis result for the message.