pub struct GoogleCloudDialogflowV2beta1MessageAnnotation {
pub contain_entities: Option<bool>,
pub parts: Option<Vec<GoogleCloudDialogflowV2beta1AnnotatedMessagePart>>,
}Expand description
Represents the result of annotation for the message.
This type is not used in any activity, and only used as part of another schema.
Fields
contain_entities: Option<bool>Required. Indicates whether the text message contains entities.
parts: Option<Vec<GoogleCloudDialogflowV2beta1AnnotatedMessagePart>>Optional. The collection of annotated message parts ordered by their position in the message. You can recover the annotated message by concatenating [AnnotatedMessagePart.text].