pub struct GoogleCloudDialogflowV2beta1OutputAudioConfig {
pub audio_encoding: Option<String>,
pub sample_rate_hertz: Option<i32>,
pub synthesize_speech_config: Option<GoogleCloudDialogflowV2beta1SynthesizeSpeechConfig>,
}Expand description
Instructs the speech synthesizer how to generate the output audio content. If this audio config is supplied in a request, it overrides all existing text-to-speech settings applied to the agent.
This type is not used in any activity, and only used as part of another schema.
Fields
audio_encoding: Option<String>Required. Audio encoding of the synthesized audio content.
sample_rate_hertz: Option<i32>The synthesis sample rate (in hertz) for this audio. If not provided, then the synthesizer will use the default sample rate based on the audio encoding. If this is different from the voice’s natural sample rate, then the synthesizer will honor this request by converting to the desired sample rate (which might result in worse audio quality).
synthesize_speech_config: Option<GoogleCloudDialogflowV2beta1SynthesizeSpeechConfig>Configuration of how speech should be synthesized.