pub struct GoogleCloudDialogflowV2beta1ResponseMessageMixedAudio {
pub segments: Option<Vec<GoogleCloudDialogflowV2beta1ResponseMessageMixedAudioSegment>>,
}Expand description
Represents an audio message that is composed of both segments synthesized from the Dialogflow agent prompts and ones hosted externally at the specified URIs.
This type is not used in any activity, and only used as part of another schema.
Fields
segments: Option<Vec<GoogleCloudDialogflowV2beta1ResponseMessageMixedAudioSegment>>Segments this audio response is composed of.