pub struct GoogleCloudDialogflowV2beta1SearchKnowledgeResponse {
pub answers: Option<Vec<GoogleCloudDialogflowV2beta1SearchKnowledgeAnswer>>,
pub rewritten_query: Option<String>,
}Expand description
The response message for Conversations.SearchKnowledge.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
answers: Option<Vec<GoogleCloudDialogflowV2beta1SearchKnowledgeAnswer>>Most relevant snippets extracted from articles in the given knowledge base, ordered by confidence.
rewritten_query: Option<String>The rewritten query used to search knowledge.