pub struct GoogleCloudDialogflowV2beta1Sentiment {
pub magnitude: Option<f32>,
pub score: Option<f32>,
}Expand description
The sentiment, such as positive/negative feeling or association, for a unit of analysis, such as the query text. See: https://cloud.google.com/natural-language/docs/basics#interpreting_sentiment_analysis_values for how to interpret the result.
This type is not used in any activity, and only used as part of another schema.
Fields
magnitude: Option<f32>A non-negative number in the [0, +inf) range, which represents the absolute magnitude of sentiment, regardless of score (positive or negative).
score: Option<f32>Sentiment score between -1.0 (negative sentiment) and 1.0 (positive sentiment).