pub struct GoogleCloudDialogflowV2beta1SpeechToTextConfig {
pub model: Option<String>,
pub speech_model_variant: Option<String>,
pub use_timeout_based_endpointing: Option<bool>,
}Expand description
Configures speech transcription for ConversationProfile.
This type is not used in any activity, and only used as part of another schema.
Fields
model: Option<String>Which Speech model to select. Select the model best suited to your domain to get best results. If a model is not explicitly specified, then Dialogflow auto-selects a model based on other parameters in the SpeechToTextConfig and Agent settings. If enhanced speech model is enabled for the agent and an enhanced version of the specified model for the language does not exist, then the speech is recognized using the standard version of the specified model. Refer to Cloud Speech API documentation for more details. If you specify a model, the following models typically have the best performance: - phone_call (best for Agent Assist and telephony) - latest_short (best for Dialogflow non-telephony) - command_and_search Leave this field unspecified to use Agent Speech settings for model selection.
speech_model_variant: Option<String>The speech model used in speech to text. SPEECH_MODEL_VARIANT_UNSPECIFIED, USE_BEST_AVAILABLE will be treated as USE_ENHANCED. It can be overridden in AnalyzeContentRequest and StreamingAnalyzeContentRequest request. If enhanced model variant is specified and an enhanced version of the specified model for the language does not exist, then it would emit an error.
use_timeout_based_endpointing: Option<bool>Use timeout based endpointing, interpreting endpointer sensitivy as seconds of timeout value.