pub struct GoogleCloudDialogflowV2beta1SuggestionFeature {
pub type_: Option<String>,
}Expand description
The type of Human Agent Assistant API suggestion to perform, and the maximum number of results to return for that type. Multiple Feature objects can be specified in the features list.
This type is not used in any activity, and only used as part of another schema.
Fields
type_: Option<String>Type of Human Agent Assistant API feature to request.