pub struct GoogleCloudDialogflowV2beta1SuggestionInput {
pub answer_record: Option<String>,
pub intent_input: Option<GoogleCloudDialogflowV2beta1IntentInput>,
pub parameters: Option<HashMap<String, Value>>,
pub text_override: Option<GoogleCloudDialogflowV2beta1TextInput>,
}Expand description
Represents the selection of a suggestion.
This type is not used in any activity, and only used as part of another schema.
Fields
answer_record: Option<String>Required. The ID of a suggestion selected by the human agent. The suggestion(s) were generated in a previous call to request Dialogflow assist. The format is: projects//locations//answerRecords/ where is an alphanumeric string.
intent_input: Option<GoogleCloudDialogflowV2beta1IntentInput>The intent to be triggered on V3 agent.
parameters: Option<HashMap<String, Value>>In Dialogflow assist for v3, the user can submit a form by sending a SuggestionInput. The form is uniquely determined by the answer_record field, which identifies a v3 QueryResult containing the current page. The form parameters are specified via the parameters field. Depending on your protocol or client library language, this is a map, associative array, symbol table, dictionary, or JSON object composed of a collection of (MapKey, MapValue) pairs: * MapKey type: string * MapKey value: parameter name * MapValue type: If parameter’s entity type is a composite entity then use map, otherwise, depending on the parameter value type, it could be one of string, number, boolean, null, list or map. * MapValue value: If parameter’s entity type is a composite entity then use map from composite entity property names to property values, otherwise, use parameter value.
text_override: Option<GoogleCloudDialogflowV2beta1TextInput>Optional. If the customer edited the suggestion before using it, include the revised text here.