pub struct GoogleCloudDialogflowV2beta1SummarizationContext {
pub few_shot_examples: Option<Vec<GoogleCloudDialogflowV2beta1FewShotExample>>,
pub output_language_code: Option<String>,
pub summarization_sections: Option<Vec<GoogleCloudDialogflowV2beta1SummarizationSection>>,
pub version: Option<String>,
}Expand description
Summarization context that customer can configure.
This type is not used in any activity, and only used as part of another schema.
Fields
few_shot_examples: Option<Vec<GoogleCloudDialogflowV2beta1FewShotExample>>Optional. List of few shot examples.
output_language_code: Option<String>Optional. The target language of the generated summary. The language code for conversation will be used if this field is empty. Supported 2.0 and later versions.
summarization_sections: Option<Vec<GoogleCloudDialogflowV2beta1SummarizationSection>>Optional. List of sections. Note it contains both predefined section sand customer defined sections.
version: Option<String>Optional. Version of the feature. If not set, default to latest version. Current candidates are [“1.0”].