pub struct GoogleCloudDialogflowV2beta1SummarizationSection {
pub definition: Option<String>,
pub key: Option<String>,
pub type_: Option<String>,
}Expand description
Represents the section of summarization.
This type is not used in any activity, and only used as part of another schema.
Fields
definition: Option<String>Optional. Definition of the section, for example, “what the customer needs help with or has question about.”
key: Option<String>Optional. Name of the section, for example, “situation”.
type_: Option<String>Optional. Type of the summarization section.