pub struct GoogleCloudDialogflowV2beta1ValidationError {
pub entries: Option<Vec<String>>,
pub error_message: Option<String>,
pub severity: Option<String>,
}Expand description
Represents a single validation error.
This type is not used in any activity, and only used as part of another schema.
Fields
entries: Option<Vec<String>>The names of the entries that the error is associated with. Format: - projects//agent, if the error is associated with the entire agent. - projects//agent/intents/, if the error is associated with certain intents. - projects//agent/intents//trainingPhrases/, if the error is associated with certain intent training phrases. - projects//agent/intents//parameters/, if the error is associated with certain intent parameters. - projects//agent/entities/, if the error is associated with certain entities.
error_message: Option<String>The detailed error message.
severity: Option<String>The severity of the error.