pub struct GoogleCloudDialogflowV2beta1HumanAgentAssistantConfigSuggestionQueryConfig {
pub confidence_threshold: Option<f32>,
pub context_filter_settings: Option<GoogleCloudDialogflowV2beta1HumanAgentAssistantConfigSuggestionQueryConfigContextFilterSettings>,
pub dialogflow_query_source: Option<GoogleCloudDialogflowV2beta1HumanAgentAssistantConfigSuggestionQueryConfigDialogflowQuerySource>,
pub document_query_source: Option<GoogleCloudDialogflowV2beta1HumanAgentAssistantConfigSuggestionQueryConfigDocumentQuerySource>,
pub knowledge_base_query_source: Option<GoogleCloudDialogflowV2beta1HumanAgentAssistantConfigSuggestionQueryConfigKnowledgeBaseQuerySource>,
pub max_results: Option<i32>,
pub sections: Option<GoogleCloudDialogflowV2beta1HumanAgentAssistantConfigSuggestionQueryConfigSections>,
}Expand description
Config for suggestion query.
This type is not used in any activity, and only used as part of another schema.
Fields
confidence_threshold: Option<f32>Confidence threshold of query result. Agent Assist gives each suggestion a score in the range [0.0, 1.0], based on the relevance between the suggestion and the current conversation context. A score of 0.0 has no relevance, while a score of 1.0 has high relevance. Only suggestions with a score greater than or equal to the value of this field are included in the results. For a baseline model (the default), the recommended value is in the range [0.05, 0.1]. For a custom model, there is no recommended value. Tune this value by starting from a very low value and slowly increasing until you have desired results. If this field is not set, it is default to 0.0, which means that all suggestions are returned. Supported features: ARTICLE_SUGGESTION, FAQ, SMART_REPLY, SMART_COMPOSE, KNOWLEDGE_SEARCH, KNOWLEDGE_ASSIST, ENTITY_EXTRACTION.
context_filter_settings: Option<GoogleCloudDialogflowV2beta1HumanAgentAssistantConfigSuggestionQueryConfigContextFilterSettings>Determines how recent conversation context is filtered when generating suggestions. If unspecified, no messages will be dropped.
dialogflow_query_source: Option<GoogleCloudDialogflowV2beta1HumanAgentAssistantConfigSuggestionQueryConfigDialogflowQuerySource>Query from Dialogflow agent. It is used by DIALOGFLOW_ASSIST, ENTITY_EXTRACTION.
document_query_source: Option<GoogleCloudDialogflowV2beta1HumanAgentAssistantConfigSuggestionQueryConfigDocumentQuerySource>Query from knowledge base document. It is used by: SMART_REPLY, SMART_COMPOSE.
knowledge_base_query_source: Option<GoogleCloudDialogflowV2beta1HumanAgentAssistantConfigSuggestionQueryConfigKnowledgeBaseQuerySource>Query from knowledgebase. It is used by: ARTICLE_SUGGESTION, FAQ.
max_results: Option<i32>Maximum number of results to return. Currently, if unset, defaults to 10. And the max number is 20.
sections: Option<GoogleCloudDialogflowV2beta1HumanAgentAssistantConfigSuggestionQueryConfigSections>Optional. The customized sections chosen to return when requesting a summary of a conversation.