pub struct GoogleCloudDialogflowV2beta1KnowledgeAnswersAnswer {
pub answer: Option<String>,
pub faq_question: Option<String>,
pub match_confidence: Option<f32>,
pub match_confidence_level: Option<String>,
pub source: Option<String>,
}Expand description
An answer from Knowledge Connector.
This type is not used in any activity, and only used as part of another schema.
Fields
answer: Option<String>The piece of text from the source knowledge base document that answers this conversational query.
faq_question: Option<String>The corresponding FAQ question if the answer was extracted from a FAQ Document, empty otherwise.
match_confidence: Option<f32>The system’s confidence score that this Knowledge answer is a good match for this conversational query. The range is from 0.0 (completely uncertain) to 1.0 (completely certain). Note: The confidence score is likely to vary somewhat (possibly even for identical requests), as the underlying model is under constant improvement. It may be deprecated in the future. We recommend using match_confidence_level which should be generally more stable.
match_confidence_level: Option<String>The system’s confidence level that this knowledge answer is a good match for this conversational query. NOTE: The confidence level for a given `` pair may change without notice, as it depends on models that are constantly being improved. However, it will change less frequently than the confidence score below, and should be preferred for referencing the quality of an answer.
source: Option<String>Indicates which Knowledge Document this answer was extracted from. Format: projects//knowledgeBases//documents/.